use axum::extract::{Query, State};
use axum::routing::get;
use axum::Json;
use axum::Router;
use sea_orm::entity::EntityTrait;
use sea_orm::query::QueryOrder;
use sea_orm::PaginatorTrait;
use serde::Deserialize;

use crate::db::entities::repo;

#[derive(Deserialize)]
pub struct Pagination {
    page: Option<u64>,
    per_page: Option<u64>,
}

pub fn router() -> Router<crate::Global> {
    Router::new().route("/repos", get(get_repos))
}

async fn get_repos(
    State(global): State<crate::Global>,
    Query(params): Query<Pagination>,
) -> crate::Result<Json<Vec<repo::Model>>> {
    let repos = repo::Entity::find()
        .order_by_asc(repo::Column::Id)
        .paginate(&global.db, params.per_page.unwrap_or(25))
        .fetch_page(params.page.unwrap_or(0))
        .await?;

    Ok(Json(repos))
}
